@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2014 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -21,6 +21,7 @@
 #define MAINWINDOW_H
 
 #include <QtGui/QMainWindow>
+#include <QSslError>
 
 #include "ui_mainwindow.h"
 
@@ -51,6 +52,7 @@ private slots:
     void onEventChanged(int aEventId, bool favouriteChanged);
     void onSearchResultChanged();
 
+    void sslErrors(QNetworkReply*,const QList<QSslError> &errors);
     void networkQueryFinished(QNetworkReply*);
     void importFromNetwork(const QString&, int conferenceId);
     void importFromFile(const QString&, int conferenceId);
